@@ -22,6 +22,13 @@
 plot.trajectory <- function(x, engine="dot", fill=scales::brewer_pal("qual"), verbose=FALSE, ...) {
   stopifnot(length(x) > 0)
 
+  # this should be done by DiagrammeR
+  # see https://github.com/r-simmer/simmer.plot/issues/19
+  if (exists(".Random.seed", where=globalenv())) {
+    currentSeed <- get(".Random.seed", pos=globalenv())
+    on.exit(assign(".Random.seed", currentSeed, pos=globalenv()))
+  } else on.exit(rm(".Random.seed", pos=globalenv()))
+
   trajectory_graph(x, fill, verbose) %>%
     DiagrammeR::add_global_graph_attrs("layout", engine, "graph") %>%
     DiagrammeR::add_global_graph_attrs("fontname", "sans-serif", "node") %>%
@@ -102,6 +109,7 @@ trajectory_graph <- function(x, fill, verbose=FALSE) {
   info <- sub(" \\}", "", out)
   info[rollbacks] <- sub("amount: ", "", info[rollbacks])
   amounts <- as.numeric(sub(" \\(.*", "", info[rollbacks]))
+  amounts <- replace(amounts, amounts < 0, Inf)
   info[rollbacks] <- sub(".*, ", "", info[rollbacks])
   resources <- sub("resource: ", "", info[c(seizes, releases)])
   resources <- sub(",* .*", "", resources)
@@ -123,11 +131,16 @@ trajectory_graph <- function(x, fill, verbose=FALSE) {
   suppressMessages({for (i in seq_along(amounts)) {
     from <- nodes[rollbacks[i],]$id
     graph <- DiagrammeR::select_nodes_by_id(graph, from)
-    try({
-      for (j in seq_len(amounts[i]))
-        graph <- DiagrammeR::trav_in(graph)
-    }, silent = TRUE)
+    indeg <- DiagrammeR::get_degree_in(graph)
     to <- as.numeric(DiagrammeR::get_selection(graph))
+    steps <- amounts[i]
+    try({
+      while (steps && indeg[indeg$id==to,]$indegree) {
+        graph <- DiagrammeR::trav_in(graph)
+        to <- as.numeric(DiagrammeR::get_selection(graph))
+        steps <- steps - 1
+      }
+    }, silent = TRUE)
     graph <- DiagrammeR::clear_selection(graph)
     r_edges <- rbind(r_edges, data.frame(from=from, to=to))
   }})
